@@ -4,7 +4,7 @@ import gzip
 import os
 import io
 import tempfile
-
+from os import environ
 from idzip import api
 
 try:
@@ -27,7 +27,8 @@ def test_idzip_file_api():
 
     dfd, dzfile = tempfile.mkstemp(suffix='.dz')
     with IdzipFile(dzfile, 'wb') as writer:
-        writer.write(data)
+        n = writer.write(data)
+        assert n == len(data)
 
     assert writer.closed
 
@@ -40,7 +41,8 @@ def test_idzip_file_api():
     gfd, gzfile = tempfile.mkstemp(suffix='.gz')
 
     with gzip.open(gzfile, 'wb') as writer:
-        writer.write(data)
+        n = writer.write(data)
+        assert n == len(data)
 
     with IdzipFile(gzfile, 'rb') as reader:
         decoded = reader.read()
@@ -55,9 +57,31 @@ def test_idzip_file_api():
 
 
 def test_large_write():
+    if environ.get("BUILDENV") == "TRAVIS":
+        return #Travis is just going to barf anyway
+    else:
+        # find the largest fraction of MAX_MEMBER_SIZE that can
+        # be allocated
+        data = b''
+        for d in range(1, 1000):
+            try:
+                data = b"a" * ((api.MAX_MEMBER_SIZE + 100) // d)
+                break
+            except MemoryError:
+                continue
+        if data == b'':
+            # no test could be performed
+            return
+        dzfile = io.BytesIO()
+        with IdzipFile(fileobj=dzfile, mode='wb') as writer:
+            n = writer.write(data)
+            assert n == len(data)
+        dzfile.seek(0)
+        with IdzipFile(fileobj=dzfile, mode='rb') as reader:
+            decoded = reader.read()
+        assert decoded == data
 
-    # find the largest fraction of MAX_MEMBER_SIZE that can
-    # be allocated
+def test_bufferedio_compat():
     data = b''
     for d in range(1, 1000):
         try:
@@ -69,10 +93,11 @@ def test_large_write():
         # no test could be performed
         return
     dzfile = io.BytesIO()
-    with IdzipFile(fileobj=dzfile, mode='wb') as writer:
-        writer.write(data)
+    with io.BufferedWriter(IdzipFile(fileobj=dzfile, mode='wb')) as writer:
+        n = writer.write(data)
+        assert n == len(data)
     dzfile.seek(0)
-    with IdzipFile(fileobj=dzfile, mode='rb') as reader:
+    with io.BufferedReader(IdzipFile(fileobj=dzfile, mode='rb')) as reader:
         decoded = reader.read()
     assert decoded == data
 
